@@ -108,7 +108,6 @@ fi
 (cd $B/bin; ln -s ../usr/bin/perl perl)
 echo -n > $B/var/lib/dpkg/status
 
-mkdir -p $B/dev/inet
 case "$arch" in
 	i386)
 		(cd $B/dev; /dev/MAKEDEV -I generic )
@@ -155,6 +154,8 @@ sed -e 's,/sbin/setup.sh,/root/setup.sh,' \
 mv $B/etc/init.d/boot.tmp $B/etc/init.d/boot
 chmod a+x $B/etc/init.d/boot
 
+(cd $B; dpkg --root=. -l) >base-contents
+
 # Locale files make the base a bit larger. Un-comment this if it becomes
 # a problem.
 # rm -f -r $B/usr/share/locale $B/usr/share/gettext $B/usr/share/nls
