@@ -18,8 +18,9 @@ last_by_version () {
 		last_by_version $b $@
 	fi
 }
- 
+
 make_paths() {
+#	set -x
 	exit=false
 	local PATHS=""
 	local i
@@ -29,7 +30,7 @@ make_paths() {
 		local p
 		local j
 		for j in $archive/*/${i}_[^a-zA-Z]*.deb \
-				updates/${i}_[^a-zA-Z]*.deb; do
+				`pwd`/updates/${i}_[^a-zA-Z]*.deb; do
 			if [ -f $j ]; then
 				f="$f $j"
 			fi
