@@ -60,16 +60,20 @@ extern int chmod_main(struct FileInfo * i, int argc, char * * argv);
 extern int chown_main(struct FileInfo * i, int argc, char * * argv);
 extern int clear_main(struct FileInfo * i, int argc, char * * argv);
 extern int date_main(struct FileInfo * i, int argc, char * * argv);
+extern int dd_main(struct FileInfo * i, int argc, char * * argv);
 extern int df_main(struct FileInfo * i, int argc, char * * argv);
+extern int dmesg_main(struct FileInfo * i, int argc, char * * argv);
 extern int dyadic_main(struct FileInfo * i, int argc, char * * argv);
 extern int false_main(struct FileInfo * i, int argc, char * * argv);
 extern int fdisk_main(struct FileInfo * i, int argc, char * * argv);
+extern int find_main(struct FileInfo * i, int argc, char * * argv);
 extern int floppy_merge_main(struct FileInfo * i, int argc, char * * argv);
 extern int halt_main(struct FileInfo * i, int argc, char * * argv);
 extern int init_main(struct FileInfo * i, int argc, char * * argv);
 extern int kill_main(struct FileInfo * i, int argc, char * * argv);
 extern int length_main(struct FileInfo * i, int argc, char * * argv);
 extern int ln_main(struct FileInfo * i, int argc, char * * argv);
+extern int losetup_main(struct FileInfo * i, int argc, char * * argv);
 extern int ls_main(struct FileInfo * i, int argc, char * * argv);
 extern int math_main(struct FileInfo * i, int argc, char * * argv);
 extern int mknod_main(struct FileInfo * i, int argc, char * * argv);
@@ -90,10 +94,12 @@ extern int true_main(struct FileInfo * i, int argc, char * * argv);
 extern int tryopen_main(struct FileInfo * i, int argc, char * * argv);
 extern int umount_main(struct FileInfo * i, int argc, char * * argv);
 extern int update_main(struct FileInfo * i, int argc, char * * argv);
+extern int zcat_main(struct FileInfo * i, int argc, char * * argv);
 
 extern int cat_fn(const struct FileInfo * f);
 extern int cp_fn(const struct FileInfo * f);
 extern int fdflush_fn(const struct FileInfo * f);
+extern int find_fn(const struct FileInfo * f);
 extern int ln_fn(const struct FileInfo * f);
 extern int mkdir_fn(const struct FileInfo * f);
 extern int more_fn(const struct FileInfo * f);
@@ -123,15 +129,19 @@ extern const char	chown_usage[];
 extern const char	clear_usage[];
 extern const char	cp_usage[];
 extern const char	date_usage[];
+extern const char	dd_usage[];
 extern const char	df_usage[];
+extern const char	dmesg_usage[];
 extern const char	false_usage[];
 extern const char	fdflush_usage[];
+extern const char	find_usage[];
 extern const char	floppy_merge_usage[];
 extern const char	halt_usage[];
 extern const char	init_usage[];
 extern const char	kill_usage[];
 extern const char	length_usage[];
 extern const char	ln_usage[];
+extern const char	losetup_usage[];
 extern const char	ls_usage[];
 extern const char	math_usage[];
 extern const char	mkdir_usage[];
@@ -156,5 +166,6 @@ extern const char	true_usage[];
 extern const char	tryopen_usage[];
 extern const char	umount_usage[];
 extern const char	update_usage[];
+extern const char	zcat_usage[];
 
 #endif
